DEFAULT_LINE_LENGTH = 79
DEFAULT_EXCLUDES = r"/(\.direnv|\.eggs|\.git|\.hg|\.mypy_cache|\.nox|\.tox|\.venv|venv|\.svn|\.ipynb_checkpoints|_build|buck-out|build|dist|__pypackages__)/"  # noqa: B950
DEFAULT_INCLUDES = r"(\.pyi?|\.ipynb)$"
STDIN_PLACEHOLDER = "__BLACK_STDIN_FILENAME__"
DEFAULT_FUNCTION_DEFINITION_EXTRA_INDENT = True
DEFAULT_CLOSING_BRACKET_EXTRA_INDENT = False
DEFAULT_SINGLE_QUOTE = True
DEFAULT_WRAP_LINE_WITH_LONG_STRING = False
DEFAULT_COLLAPSE_NESTED_BRACKETS = True
DEFAULT_WRAP_PRAGMA_COMMENTS = False
DEFAULT_BASE_INDENTATION_SPACES = 4
DEFAULT_OTHER_LINE_CONTINUATION_EXTRA_INDENT = False
DEFAULT_USE_TABS = False
DEFAULT_TAB_WIDTH = 4
